@@ -12,7 +12,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2012 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    Release 2.3.x SVN: $Id: global.php 5034 2012-07-12 01:29:35Z fishbone $
+ * @version    Release 2.3.x SVN: $Id: global.php 5051 2012-07-23 02:24:23Z fishbone $
  * @link       http://www.magic3.org
  */
 if (defined("M3_SYSTEM_DEFINE_INCLUDED")) return;
@@ -48,8 +48,8 @@ define('M3_ENCODING',	'UTF-8');	// 内部エンコーディング
 // ########## システム関係 ##########
 // システム基本情報
 define('M3_SYSTEM_NAME',			'Magic3');		// システム名称
-define('M3_SYSTEM_VERSION',			'2.3.10');		// システムのバージョン
-define('M3_SYSTEM_RELEASE_DATE',	'2012/7/9');	// システムのリリース日付
+define('M3_SYSTEM_VERSION',			'2.3.11');		// システムのバージョン
+define('M3_SYSTEM_RELEASE_DATE',	'2012/7/12');	// システムのリリース日付
 define('M3_SYSTEM_ID',				'M3');			// コンポーネント識別用ID
 define('M3_SYSTEM_DESCRIPTION',		'Magic3 is open source cms and web communication platform.');		// システムの説明
 define('M3_SYSTEM_MIN_MEMORY',		'16M');			// 最小メモリ使用量
@@ -93,7 +93,11 @@ define('M3_TAG_MACRO_CONTENT_KEY',	'CT_');									// コンテンツ置換キ
 define('M3_TAG_MACRO_ITEM',			'ITEM');								// 項目置換キー
 define('M3_TAG_MACRO_TITLE',		'TITLE');								// タイトル置換キー
 define('M3_TAG_MACRO_BODY',			'BODY');								// 本文置換キー
+define('M3_TAG_MACRO_FILES',		'FILES');								// 添付ファイル置換キー
+define('M3_TAG_MACRO_PAGES',		'PAGES');								// ページリンク置換キー
+define('M3_TAG_MACRO_LINKS',		'LINKS');								// 関連リンク置換キー
 define('M3_TAG_MACRO_WIDGET',		'WIDGET');								// ウィジェット埋め込みキー
+define('M3_TAG_MACRO_CONTENT_ID',			'CT_ID');						// コンテンツ置換キー(コンテンツID)
 define('M3_TAG_MACRO_CONTENT_NOW',			'CT_NOW');						// コンテンツ置換キー(表示時日時)
 define('M3_TAG_MACRO_CONTENT_CREATE_DT',	'CT_CREATE_DT');				// コンテンツ置換キー(作成日時)
 define('M3_TAG_MACRO_CONTENT_UPDATE_DT',	'CT_UPDATE_DT');				// コンテンツ置換キー(更新日時)
