@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2011 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: accessManager.php 4759 2012-03-15 11:09:54Z fishbone $
+ * @version    SVN: $Id: accessManager.php 4909 2012-05-17 12:44:50Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once(M3_SYSTEM_INCLUDE_PATH . '/common/core.php');
@@ -207,6 +207,8 @@ class AccessManager extends Core
 	{
 		global $gRequestManager;
 		global $gEnvManager;
+		global $gAccessManager;
+		global $gInstanceManager;
 		
 		// ユーザ情報が存在しているときは、ユーザIDを登録する
 		$userId = 0;
@@ -240,6 +242,9 @@ class AccessManager extends Core
 		
 		// アクセスログのシリアルNoを保存
 		$this->_accessLogSerialNo = $this->db->accessLog($userId, $cookieVal, $session, $ip, $method, $uri, $referer, $request, $agent, $language, $path, $isCookie, $isCrawler);
+		
+		// 即時アクセス解析
+		if (M3_SYSTEM_REALTIME_ANALYTICS) $gInstanceManager->getAnalyzeManager()->realtimeAnalytics($this->_accessLogSerialNo, $cookieVal);
 	}
 	/**
 	 * アクセス元のIPを取得
