@@ -8,9 +8,9 @@
  *
  * @package    Magic3 Framework
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
- * @copyright  Copyright 2006-2011 Magic3 Project.
+ * @copyright  Copyright 2006-2012 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: admin_mainAdjustwidgetWidgetContainer.php 4150 2011-05-24 07:06:49Z fishbone $
+ * @version    SVN: $Id: admin_mainAdjustwidgetWidgetContainer.php 4901 2012-05-03 12:18:00Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getCurrentWidgetContainerPath() .	'/admin_mainBaseWidgetContainer.php');
@@ -101,6 +101,11 @@ class admin_mainAdjustwidgetWidgetContainer extends admin_mainBaseWidgetContaine
 		$titleVisible = ($request->trimValueOf('item_title_visible') == 'on') ? 1 : 0;		// タイトルを表示するかどうか
 		$useRender = ($request->trimValueOf('item_use_render') == 'on') ? 1 : 0;		// Joomla!の描画処理を使用するかどうか
 		$widgetId = $request->trimValueOf('widget_id');			// ウィジェットID
+		$topContent = $request->valueOf('item_top_content');			// 補助コンテンツ(上)
+		$bottomContent = $request->valueOf('item_bottom_content');			// 補助コンテンツ(下)
+		$showReadmore = ($request->trimValueOf('item_show_readmore') == 'on') ? 1 : 0;		// もっと読むボタンを表示するかどうか
+		$readmoreTitle = $request->trimValueOf('item_readmore_title');			// もっと読むボタンタイトル
+		$readmoreUrl = $request->trimValueOf('item_readmore_url');			// もっと読むリンク先URL
 		
 		// 「その他」設定
 		$shared = ($request->trimValueOf('item_shared') == 'on') ? 1 : 0;		// 共通属性があるかどうか
@@ -158,7 +163,7 @@ class admin_mainAdjustwidgetWidgetContainer extends admin_mainBaseWidgetContaine
 				if (!empty($marginLeft)) $style .= 'padding-left:' . $marginLeft . 'px;';
 				if (!empty($marginRight)) $style .= 'padding-right:' . $marginRight . 'px;';
 				
-				$ret = $this->db->updatePageDefInfo($defSerial, $style, $title, $titleVisible, $useRender);
+				$ret = $this->db->updatePageDefInfo($defSerial, $style, $title, $titleVisible, $useRender, $topContent, $bottomContent, $showReadmore, $readmoreTitle, $readmoreUrl);
 				if ($ret){		// データ追加成功のとき
 					$this->setMsg(self::MSG_GUIDANCE, $this->_('Configration updated.'));		// データを更新しました
 					$replaceNew = true;			// データを再取得
@@ -234,7 +239,12 @@ class admin_mainAdjustwidgetWidgetContainer extends admin_mainBaseWidgetContaine
 			$titleVisible = 1;		// タイトルを表示するかどうか
 			$useRender = 1;		// Joomla!の描画処理を使用するかどうか
 			$widgetId = '';	// ウィジェットID
-			
+			$topContent = '';			// 補助コンテンツ(上)
+			$bottomContent = '';			// 補助コンテンツ(下)
+			$showReadmore = 0;		// もっと読むボタンを表示するかどうか
+			$readmoreTitle = '';			// もっと読むボタンタイトル
+			$readmoreUrl = '';			// もっと読むリンク先URL
+		
 			// 「その他」設定
 			$shared = 0;		// 共通属性があるかどうか
 			$viewControlType = 0;		// 表示制御タイプ
@@ -280,7 +290,12 @@ class admin_mainAdjustwidgetWidgetContainer extends admin_mainBaseWidgetContaine
 				$titleVisible = $row['pd_title_visible'];			// タイトルを表示するかどうか
 				$useRender = $row['pd_use_render'];		// Joomla!の描画処理を使用するかどうか
 				$widgetId = $row['pd_widget_id'];	// ウィジェットID
-				
+				$topContent = $row['pd_top_content'];			// 補助コンテンツ(上)
+				$bottomContent = $row['pd_bottom_content'];			// 補助コンテンツ(下)
+				$showReadmore = $row['pd_show_readmore'];		// もっと読むボタンを表示するかどうか
+				$readmoreTitle = $row['pd_readmore_title'];			// もっと読むボタンタイトル
+				$readmoreUrl = $row['pd_readmore_url'];			// もっと読むリンク先URL
+			
 				$shared = 0;		// 共通属性があるかどうか
 				if (empty($row['pd_sub_id'])) $shared = 1;	// 共通ウィジェットのとき
 				$viewControlType = $row['pd_view_control_type'];		// 表示制御タイプ
@@ -309,7 +324,12 @@ class admin_mainAdjustwidgetWidgetContainer extends admin_mainBaseWidgetContaine
 		if (!empty($titleVisible)) $this->tmpl->addVar("_widget", "title_visible", 'checked');		// タイトルを表示するかどうか
 		if (!empty($useRender)) $this->tmpl->addVar("_widget", "use_render", 'checked');		// Joomla!の描画処理を使用するかどうか
 		$this->tmpl->addVar("_widget", "widget_id", $widgetId);				// ウィジェットID
-		
+		$this->tmpl->addVar("_widget", "top_content", $topContent);			// 補助コンテンツ(上)
+		$this->tmpl->addVar("_widget", "bottom_content", $bottomContent);			// 補助コンテンツ(下)
+		if (!empty($showReadmore)) $this->tmpl->addVar("_widget", "show_readmore_checked", 'checked');		// もっと読むボタンを表示するかどうか
+		$this->tmpl->addVar("_widget", "readmore_title", $readmoreTitle);			// もっと読むボタンタイトル
+		$this->tmpl->addVar("_widget", "readmore_url", $readmoreUrl);			// もっと読むリンク先URL
+			
 		// 「その他」設定
 		$checked = '';
 		if ($shared) $checked = 'checked';		// 共通属性があるかどうか
@@ -441,6 +461,12 @@ class admin_mainAdjustwidgetWidgetContainer extends admin_mainBaseWidgetContaine
 		$localeText['label_position'] = $this->_('Contents Position');			// テキスト表示位置
 		$localeText['label_render'] = $this->_('Render');// 描画処理
 		$localeText['label_use_joomla_render'] = $this->_('Render by Joomla! style');// Joomla!スタイルの描画処理を使用
+		$localeText['label_top_content'] = $this->_('Additional Top Content');// 補助コンテンツ(上)
+		$localeText['label_bottom_content'] = $this->_('Additional Bottom Content');// 補助コンテンツ(下)
+		$localeText['label_readmore'] = $this->_('Readmore Button');// 「もっと読む」ボタン
+		$localeText['label_readmore_title'] = $this->_('Title:');// タイトル：
+		$localeText['label_readmore_url'] = $this->_('Url:');// URL：
+		
 		$localeText['label_view_control'] = $this->_('View Control');// 表示制御
 		$localeText['label_shared_attr'] = $this->_('Page Shared Attribute');// ページ共通属性
 		$localeText['label_on'] = $this->_('On');// オン
