@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2012 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: admin_default_contentContentWidgetContainer.php 5027 2012-07-09 06:24:07Z fishbone $
+ * @version    SVN: $Id: admin_default_contentContentWidgetContainer.php 5029 2012-07-10 13:15:38Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getWidgetContainerPath('default_content') . '/admin_default_contentBaseWidgetContainer.php');
@@ -551,7 +551,7 @@ class admin_default_contentContentWidgetContainer extends admin_default_contentB
 				$destStr = $this->gInstance->getAjaxManager()->createJsonString($resultObj);
 			}
 			$destStr = htmlspecialchars($destStr, ENT_NOQUOTES);
-			header("Content-type: text/xml; charset=utf-8");
+			header("Content-type: application/json; charset=utf-8");
 			echo $destStr;
 			
 			// システム強制終了
