@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2012 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: admin_default_contentOtherWidgetContainer.php 5030 2012-07-11 03:57:59Z fishbone $
+ * @version    SVN: $Id: admin_default_contentOtherWidgetContainer.php 5047 2012-07-20 09:58:03Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getWidgetContainerPath('default_content') . '/admin_default_contentBaseWidgetContainer.php');
@@ -61,6 +61,7 @@ class admin_default_contentOtherWidgetContainer extends admin_default_contentBas
 		$showEdit	= ($request->trimValueOf('item_show_edit') == 'on') ? 1 : 0;			// 編集ボタンを表示するかどうか
 		$usePassword	= ($request->trimValueOf('item_use_password') == 'on') ? 1 : 0;		// パスワードを使用するかどうか
 		$passwordContent = $request->valueOf('item_password_content');					// パスワード入力画面用コンテンツ
+		$layoutViewDetail = $request->valueOf('item_layout_view_detail');					// コンテンツレイアウト(詳細表示)
 		
 		// デバイスタイプごとの処理
 		if (default_contentCommonDef::$_deviceType == 2){		// スマートフォンの場合
@@ -81,11 +82,14 @@ class admin_default_contentOtherWidgetContainer extends admin_default_contentBas
 				if (default_contentCommonDef::$_deviceType == 2){		// スマートフォンの場合
 					$paramObj->jqueryMobileFormat = $jqueryMobileFormat;			// jQueryMobile用のフォーマットで出力するかどうか
 				}
-				
 				$ret = $this->updateWidgetParamObj($paramObj);
-				if ($ret) $ret = self::$_mainDb->updateConfig(default_contentCommonDef::$CF_USE_PASSWORD, $usePassword);		// パスワードを使用するかどうか
-				if ($ret) $ret = self::$_mainDb->updateConfig(default_contentCommonDef::$CF_PASSWORD_CONTENT, $passwordContent);		// パスワード入力画面用コンテンツ
-		
+				
+				if (empty($layoutViewDetail)) $layoutViewDetail = default_contentCommonDef::DEFAULT_CONTENT_LAYOUT;
+				if ($ret) $ret = self::$_mainDb->updateConfig(default_contentCommonDef::$_contentType, default_contentCommonDef::$CF_USE_PASSWORD, $usePassword);		// パスワードを使用するかどうか
+				if ($ret) $ret = self::$_mainDb->updateConfig(default_contentCommonDef::$_contentType, default_contentCommonDef::$CF_PASSWORD_CONTENT, $passwordContent);		// パスワード入力画面用コンテンツ
+				if ($ret) $ret = self::$_mainDb->updateConfig(default_contentCommonDef::$_contentType, default_contentCommonDef::$CF_LAYOUT_VIEW_DETAIL, $layoutViewDetail);
+																												// コンテンツレイアウト(詳細表示)
+				
 				if ($ret){
 					$this->setMsg(self::MSG_GUIDANCE, 'データを更新しました');
 				} else {
@@ -101,6 +105,7 @@ class admin_default_contentOtherWidgetContainer extends admin_default_contentBas
 			$showEdit = 1;			// 編集ボタンを表示するかどうか
 			$usePassword = 0;		// パスワードを使用するかどうか
 			$passwordContent = '';		// パスワード入力画面用コンテンツ
+			$layoutViewDetail = default_contentCommonDef::DEFAULT_CONTENT_LAYOUT;					// コンテンツレイアウト(詳細表示)
 			
 			// デバイスタイプごとの処理
 			if (default_contentCommonDef::$_deviceType == 2){		// スマートフォンの場合
@@ -120,8 +125,9 @@ class admin_default_contentOtherWidgetContainer extends admin_default_contentBas
 				}
 			}
 			
-			$usePassword = self::$_mainDb->getConfig(default_contentCommonDef::$CF_USE_PASSWORD);		// パスワードを使用するかどうか
-			$passwordContent = self::$_mainDb->getConfig(default_contentCommonDef::$CF_PASSWORD_CONTENT);		// パスワード入力画面用コンテンツ
+			$usePassword = self::$_mainDb->getConfig(default_contentCommonDef::$_contentType, default_contentCommonDef::$CF_USE_PASSWORD);		// パスワードを使用するかどうか
+			$passwordContent = self::$_mainDb->getConfig(default_contentCommonDef::$_contentType, default_contentCommonDef::$CF_PASSWORD_CONTENT);		// パスワード入力画面用コンテンツ
+			$layoutViewDetail = self::$_mainDb->getConfig(default_contentCommonDef::$_contentType, default_contentCommonDef::$CF_LAYOUT_VIEW_DETAIL);		// コンテンツレイアウト(詳細表示)
 		}
 		
 		// 画面に書き戻す
@@ -139,6 +145,7 @@ class admin_default_contentOtherWidgetContainer extends admin_default_contentBas
 		if (!empty($usePassword)) $checked = 'checked';
 		$this->tmpl->addVar("_widget", "use_password", $checked);		// パスワードを使用するかどうか
 		$this->tmpl->addVar("_widget", "password_content", $passwordContent);		// パスワード入力画面用コンテンツ
+		$this->tmpl->addVar("_widget", "layout_view_detail", $layoutViewDetail);		// コンテンツレイアウト(詳細表示)
 		
 		// デバイスタイプごとの画面作成
 		switch (default_contentCommonDef::$_deviceType){
