@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2012 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: default_contentDb.php 4970 2012-06-15 10:51:03Z fishbone $
+ * @version    SVN: $Id: default_contentDb.php 5047 2012-07-20 09:58:03Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getDbPath() . '/baseDb.php');
@@ -20,50 +20,56 @@ class default_contentDb extends BaseDb
 	/**
 	 * 汎用コンテンツ定義値を取得をすべて取得
 	 *
+	 * @param string $contentType	コンテンツタイプ
 	 * @param array  $rows			レコード
 	 * @return bool					1行以上取得 = true, 取得なし= false
 	 */
-	function getAllConfig(&$rows)
+	function getAllConfig($contentType, &$rows)
 	{
 		$queryStr  = 'SELECT * FROM content_config ';
+		$queryStr .=   'WHERE ng_type = ? ';
 		$queryStr .=   'ORDER BY ng_index';
-		$retValue = $this->selectRecords($queryStr, array(), $rows);
+		$retValue = $this->selectRecords($queryStr, array($contentType), $rows);
 		return $retValue;
 	}
 	/**
 	 * 汎用コンテンツ定義値を取得
 	 *
-	 * @param string $key		キーとなる項目値
-	 * @return string $value	値
+	 * @param string $contentType	コンテンツタイプ
+	 * @param string $key			キーとなる項目値
+	 * @return string $value		値
 	 */
-	function getConfig($key)
+	function getConfig($contentType, $key)
 	{
 		$retValue = '';
-		$queryStr = 'SELECT ng_value FROM content_config ';
-		$queryStr .=  'WHERE ng_id  = ?';
-		$ret = $this->selectRecord($queryStr, array($key), $row);
+		$queryStr  = 'SELECT ng_value FROM content_config ';
+		$queryStr .=   'WHERE ng_type = ? ';
+		$queryStr .=     'AND ng_id  = ? ';
+		$ret = $this->selectRecord($queryStr, array($contentType, $key), $row);
 		if ($ret) $retValue = $row['ng_value'];
 		return $retValue;
 	}
 	/**
 	 * 汎用コンテンツ定義値を更新
 	 *
-	 * @param string $key		キーとなる項目値
-	 * @param string $value		値
-	 * @return					true = 正常、false=異常
+	 * @param string $contentType	コンテンツタイプ
+	 * @param string $key			キーとなる項目値
+	 * @param string $value			値
+	 * @return						true = 正常、false=異常
 	 */
-	function updateConfig($key, $value)
+	function updateConfig($contentType, $key, $value)
 	{
 		// データの確認
-		$queryStr = 'SELECT ng_value FROM content_config ';
-		$queryStr .=  'WHERE ng_id  = ?';
-		$ret = $this->isRecordExists($queryStr, array($key));
+		$queryStr  = 'SELECT ng_value FROM content_config ';
+		$queryStr .=   'WHERE ng_type = ? ';
+		$queryStr .=     'AND ng_id  = ? ';
+		$ret = $this->isRecordExists($queryStr, array($contentType, $key));
 		if ($ret){
-			$queryStr = "UPDATE content_config SET ng_value = ? WHERE ng_id = ?";
-			return $this->execStatement($queryStr, array($value, $key));
+			$queryStr = "UPDATE content_config SET ng_value = ? WHERE ng_type = ? AND ng_id = ?";
+			return $this->execStatement($queryStr, array($value, $contentType, $key));
 		} else {
-			$queryStr = "INSERT INTO content_config (ng_id, ng_value) VALUES (?, ?)";
-			return $this->execStatement($queryStr, array($key, $value));
+			$queryStr = "INSERT INTO content_config (ng_type, ng_id, ng_value) VALUES (?, ?, ?)";
+			return $this->execStatement($queryStr, array($contentType, $key, $value));
 		}
 	}
 	/**
