@@ -10,12 +10,12 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2011 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: event_mainCalendarWidgetContainer.php 4010 2011-02-22 09:40:40Z fishbone $
+ * @version    SVN: $Id: event_mainCalendarWidgetContainer.php 5055 2012-07-23 02:50:17Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getCurrentWidgetContainerPath() .	'/event_mainBaseWidgetContainer.php');
 require_once($gEnvManager->getCurrentWidgetDbPath() . '/event_mainDb.php');
-require_once($gEnvManager->getLibPath()			. '/Calendar-0.5.3/Month/Weekdays.php');
+require_once(CALENDAR_ROOT			. 'Month/Weekdays.php');
 
 class event_mainCalendarWidgetContainer extends event_mainBaseWidgetContainer
 {
