@@ -8,9 +8,9 @@
  *
  * @package    Magic3 Framework
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
- * @copyright  Copyright 2006-2008 Magic3 Project.
+ * @copyright  Copyright 2006-2009 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: template.inc.php 1155 2008-10-29 04:23:48Z fishbone $
+ * @version    SVN: $Id: template.inc.php 1601 2009-03-21 05:51:06Z fishbone $
  * @link       http://www.magic3.org
  */
 
@@ -87,7 +87,7 @@ function plugin_template_action()
 	$s_page  = ($page == '') ? str_replace('$1', $s_refer, $_msg_template_page) : $_page;
 	$postScript = $script . WikiParam::convQuery('?');
 	$ret     = <<<EOD
-<form action="$postScript" method="post">
+<form action="$postScript" method="post" class="form">
  <div>
   <input type="hidden" name="plugin" value="template" />
   <input type="hidden" name="refer"  value="$s_refer" />
@@ -95,27 +95,13 @@ function plugin_template_action()
   $_msg_template_end   <select name="end"   size="10">$end_select</select><br /><br />
   <label for="_p_template_refer">$_msg_template_refer</label>
   <input type="text" name="page" id="_p_template_refer" value="$s_page" />
-  <input type="submit" name="submit" value="$_btn_template_create" /> $tag
+  <input type="submit" name="submit" class="button" value="$_btn_template_create" /> $tag
  </div>
 </form>
 EOD;
-/*
-	$ret     = <<<EOD
-<form action="$script" method="post">
- <div>
-  <input type="hidden" name="plugin" value="template" />
-  <input type="hidden" name="refer"  value="$s_refer" />
-  $_msg_template_start <select name="begin" size="10">$begin_select</select><br /><br />
-  $_msg_template_end   <select name="end"   size="10">$end_select</select><br /><br />
-  <label for="_p_template_refer">$_msg_template_refer</label>
-  <input type="text" name="page" id="_p_template_refer" value="$s_page" />
-  <input type="submit" name="submit" value="$_btn_template_create" /> $tag
- </div>
-</form>
-EOD;*/
+
 	$retvar['msg']  = ($msg == '') ? $_title_template : $msg;
 	$retvar['body'] = $ret;
-
 	return $retvar;
 }
 ?>
